"use strict";

exports.__esModule = true;
exports.useCheckbox = useCheckbox;

var _chakraUiHooks = require("@hackr/chakra-ui-hooks");

var _chakraUiUtils = require("@hackr/chakra-ui-utils");

var _chakraUiVisuallyHidden = require("@hackr/chakra-ui-visually-hidden");

var _react = require("react");

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

/**
 * useCheckbox that provides all the state and focus management logic
 * for a checkbox. It is consumed by the `Checkbox` component
 *
 * @see Docs https://chakra-ui.com/components/useCheckbox
 */
function useCheckbox(props) {
  if (props === void 0) {
    props = {};
  }

  var _props = props,
      defaultIsChecked = _props.defaultIsChecked,
      checkedProp = _props.isChecked,
      isFocusable = _props.isFocusable,
      isDisabled = _props.isDisabled,
      isReadOnly = _props.isReadOnly,
      isRequired = _props.isRequired,
      onChange = _props.onChange,
      isIndeterminate = _props.isIndeterminate,
      isInvalid = _props.isInvalid,
      name = _props.name,
      value = _props.value,
      id = _props.id,
      htmlProps = _objectWithoutPropertiesLoose(_props, ["defaultIsChecked", "isChecked", "isFocusable", "isDisabled", "isReadOnly", "isRequired", "onChange", "isIndeterminate", "isInvalid", "name", "value", "id"]);

  var _useBoolean = (0, _chakraUiHooks.useBoolean)(),
      isFocused = _useBoolean[0],
      setFocused = _useBoolean[1];

  var _useBoolean2 = (0, _chakraUiHooks.useBoolean)(),
      isHovered = _useBoolean2[0],
      setHovered = _useBoolean2[1];

  var _useBoolean3 = (0, _chakraUiHooks.useBoolean)(),
      isActive = _useBoolean3[0],
      setActive = _useBoolean3[1];

  var ref = (0, _react.useRef)(null);

  var _useState = (0, _react.useState)(!!defaultIsChecked),
      checkedState = _useState[0],
      setCheckedState = _useState[1];

  var _useControllableProp = (0, _chakraUiHooks.useControllableProp)(checkedProp, checkedState),
      isControlled = _useControllableProp[0],
      isChecked = _useControllableProp[1];

  var handleChange = (0, _react.useCallback)(function (event) {
    if (isReadOnly || isDisabled) {
      event.preventDefault();
      return;
    }

    if (!isControlled) {
      if (isChecked) {
        setCheckedState(event.target.checked);
      } else {
        setCheckedState(isIndeterminate ? true : event.target.checked);
      }
    }

    onChange == null ? void 0 : onChange(event);
  }, [isReadOnly, isDisabled, isChecked, isControlled, isIndeterminate, onChange]);
  (0, _chakraUiHooks.useSafeLayoutEffect)(function () {
    if (ref.current) {
      ref.current.indeterminate = Boolean(isIndeterminate);
    }
  }, [isIndeterminate]);
  var trulyDisabled = isDisabled && !isFocusable;
  var onKeyDown = (0, _react.useCallback)(function (event) {
    if (event.key === " ") {
      setActive.on();
    }
  }, [setActive]);
  var onKeyUp = (0, _react.useCallback)(function (event) {
    if (event.key === " ") {
      setActive.off();
    }
  }, [setActive]);
  /**
   * Sync state with uncontrolled form libraries like `react-hook-form`.
   *
   * These libraries set the checked value for input fields
   * using their refs. For the checkbox, it sets `ref.current.checked = true | false` directly.
   *
   * This means the `isChecked` state will get out of sync with `ref.current.checked`,
   * even though the input validation with work, the UI will not be up to date.
   *
   * Let's correct that by checking and syncing the state accordingly.
   */

  (0, _chakraUiHooks.useSafeLayoutEffect)(function () {
    if (!ref.current) return;
    var notInSync = ref.current.checked && !isChecked || !ref.current.checked && isChecked;

    if (notInSync) {
      setCheckedState(ref.current.checked);
    }
  }, [ref.current]);

  var getCheckboxProps = function getCheckboxProps(props, forwardedRef) {
    if (props === void 0) {
      props = {};
    }

    if (forwardedRef === void 0) {
      forwardedRef = null;
    }

    var onPressDown = function onPressDown(event) {
      // On mousedown, the input blurs and returns focus to the `body`,
      // we need to prevent this. Native checkboxes keeps focus on `input`
      event.preventDefault();
      setActive.on();
    };

    return _extends({}, props, {
      ref: forwardedRef,
      "data-active": (0, _chakraUiUtils.dataAttr)(isActive),
      "data-hover": (0, _chakraUiUtils.dataAttr)(isHovered),
      "data-checked": (0, _chakraUiUtils.dataAttr)(isChecked),
      "data-focus": (0, _chakraUiUtils.dataAttr)(isFocused),
      "data-indeterminate": (0, _chakraUiUtils.dataAttr)(isIndeterminate),
      "data-disabled": (0, _chakraUiUtils.dataAttr)(isDisabled),
      "data-invalid": (0, _chakraUiUtils.dataAttr)(isInvalid),
      "data-readonly": (0, _chakraUiUtils.dataAttr)(isReadOnly),
      "aria-hidden": true,
      onMouseDown: (0, _chakraUiUtils.callAllHandlers)(props.onMouseDown, onPressDown),
      onMouseUp: (0, _chakraUiUtils.callAllHandlers)(props.onMouseUp, setActive.off),
      onMouseEnter: (0, _chakraUiUtils.callAllHandlers)(props.onMouseEnter, setHovered.on),
      onMouseLeave: (0, _chakraUiUtils.callAllHandlers)(props.onMouseLeave, setHovered.off)
    });
  };

  var getInputProps = function getInputProps(props, forwardedRef) {
    if (props === void 0) {
      props = {};
    }

    if (forwardedRef === void 0) {
      forwardedRef = null;
    }

    return _extends({}, props, {
      ref: (0, _chakraUiUtils.mergeRefs)(ref, forwardedRef),
      type: "checkbox",
      name: name,
      value: value,
      id: id,
      onChange: (0, _chakraUiUtils.callAllHandlers)(props.onChange, handleChange),
      onBlur: (0, _chakraUiUtils.callAllHandlers)(props.onBlur, setFocused.off),
      onFocus: (0, _chakraUiUtils.callAllHandlers)(props.onFocus, setFocused.on),
      onKeyDown: (0, _chakraUiUtils.callAllHandlers)(props.onKeyDown, onKeyDown),
      onKeyUp: (0, _chakraUiUtils.callAllHandlers)(props.onKeyUp, onKeyUp),
      required: isRequired,
      checked: isChecked,
      disabled: trulyDisabled,
      readOnly: isReadOnly,
      "aria-invalid": isInvalid,
      "aria-disabled": isDisabled,
      style: _chakraUiVisuallyHidden.visuallyHiddenStyle
    });
  };

  var getLabelProps = function getLabelProps(props, forwardedRef) {
    if (props === void 0) {
      props = {};
    }

    if (forwardedRef === void 0) {
      forwardedRef = null;
    }

    return _extends({}, props, {
      ref: forwardedRef,
      onMouseDown: (0, _chakraUiUtils.callAllHandlers)(props.onMouseDown, stopEvent),
      onTouchStart: (0, _chakraUiUtils.callAllHandlers)(props.onTouchStart, stopEvent),
      "data-disabled": (0, _chakraUiUtils.dataAttr)(isDisabled),
      "data-checked": (0, _chakraUiUtils.dataAttr)(isChecked),
      "data-invalid": (0, _chakraUiUtils.dataAttr)(isInvalid)
    });
  };

  return {
    state: {
      isInvalid: isInvalid,
      isFocused: isFocused,
      isChecked: isChecked,
      isActive: isActive,
      isHovered: isHovered,
      isIndeterminate: isIndeterminate,
      isDisabled: isDisabled,
      isReadOnly: isReadOnly,
      isRequired: isRequired
    },
    getCheckboxProps: getCheckboxProps,
    getInputProps: getInputProps,
    getLabelProps: getLabelProps,
    htmlProps: htmlProps
  };
}
/**
 * Prevent `onBlur` being fired when the checkbox label is touched
 */


function stopEvent(event) {
  event.preventDefault();
  event.stopPropagation();
}
//# sourceMappingURL=use-checkbox.js.map