function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import { useState, useCallback } from "react";
import { useControllableProp } from "@hackr/chakra-ui-hooks";
import { isInputEvent, addItem, removeItem } from "@hackr/chakra-ui-utils";

/**
 * React hook that provides all the state management logic
 * for a group of checkboxes.
 *
 * It is consumed by the `CheckboxGroup` component
 */
export function useCheckboxGroup(props) {
  if (props === void 0) {
    props = {};
  }

  var {
    defaultValue,
    value: valueProp,
    onChange: onChangeProp,
    isNative
  } = props;
  var [valueState, setValue] = useState(defaultValue || []);
  var [isControlled, value] = useControllableProp(valueProp, valueState);
  var updateValue = useCallback(nextState => {
    if (!isControlled) {
      setValue(nextState);
    }

    onChangeProp == null ? void 0 : onChangeProp(nextState);
  }, [isControlled, onChangeProp]);
  var onChange = useCallback(eventOrValue => {
    if (!value) return;
    var isChecked = isInputEvent(eventOrValue) ? eventOrValue.target.checked : !value.includes(eventOrValue);
    var selectedValue = isInputEvent(eventOrValue) ? eventOrValue.target.value : eventOrValue;
    var nextValue = isChecked ? addItem(value, selectedValue) : removeItem(value, selectedValue);
    updateValue(nextValue);
  }, [updateValue, value]);
  return {
    value,
    onChange,
    setValue: updateValue,
    getCheckboxProps: function getCheckboxProps(props) {
      if (props === void 0) {
        props = {};
      }

      var checkedKey = isNative ? "checked" : "isChecked";
      return _extends({}, props, {
        [checkedKey]: value.includes(props.value),
        onChange
      });
    }
  };
}
//# sourceMappingURL=use-checkbox-group.js.map