import { PropsOf, SystemProps, ThemingProps, HTMLChakraProps } from "@hackr/chakra-ui-system";
import { Omit } from "@hackr/chakra-ui-utils";
import * as React from "react";
import { UseCheckboxProps } from "./use-checkbox";
declare type Omitted = "size" | "checked" | "defaultChecked" | "onChange" | "onBlur" | "value";
declare type StyledControlProps = Omit<HTMLChakraProps<"div">, Omitted>;
declare type BaseInputProps = Pick<PropsOf<"input">, "onBlur" | "checked" | "defaultChecked">;
export interface CheckboxProps extends StyledControlProps, BaseInputProps, ThemingProps, UseCheckboxProps {
    /**
     * The spacing between the checkbox and its label text
     * @default 0.5rem
     * @type SystemProps["marginLeft"]
     */
    spacing?: SystemProps["marginLeft"];
    /**
     * The color of the checkbox icon when checked or indeterminate
     */
    iconColor?: string;
    /**
     * The size of the checkbox icon when checked or indeterminate
     */
    iconSize?: string | number;
    /**
     * The checked icon to use
     *
     * @type React.ReactElement
     * @default CheckboxIcon
     */
    icon?: React.ReactElement;
}
/**
 * Checkbox
 *
 * React component used in forms when a user needs to select
 * multiple values from several options.
 *
 * @see Docs https://chakra-ui.com/components/checkbox
 */
export declare const Checkbox: import("@hackr/chakra-ui-system").ComponentWithAs<"input", CheckboxProps>;
export {};
