import { PropGetter } from "@hackr/chakra-ui-utils";
import { ChangeEvent } from "react";
export interface UseCheckboxProps {
    /**
     * If `true`, the checkbox will be checked.
     * You'll need to pass `onChange` to update its value (since it is now controlled)
     */
    isChecked?: boolean;
    /**
     * If `true`, the checkbox will be indeterminate.
     * This only affects the icon shown inside checkbox
     * and does not modify the isChecked property.
     */
    isIndeterminate?: boolean;
    /**
     * If `true`, the checkbox will be disabled
     */
    isDisabled?: boolean;
    /**
     * If `true` and `isDisabled` is passed, the checkbox will
     * remain tabbable but not interactive
     */
    isFocusable?: boolean;
    /**
     * If `true`, the checkbox will be readonly
     */
    isReadOnly?: boolean;
    /**
     * If `true`, the checkbox is marked as invalid.
     * Changes style of unchecked state.
     */
    isInvalid?: boolean;
    /**
     * If `true`, the checkbox input is marked as required,
     * and `required` attribute will be added
     */
    isRequired?: boolean;
    /**
     * If `true`, the checkbox will be initially checked.
     */
    defaultIsChecked?: boolean;
    /**
     * The callback invoked when the checked state of the `Checkbox` changes..
     */
    onChange?: (event: ChangeEvent<HTMLInputElement>) => void;
    /**
     * The name of the input field in a checkbox
     * (Useful for form submission).
     */
    name?: string;
    /**
     * The value to be used in the checkbox input.
     * This is the value that will be returned on form submission.
     */
    value?: string | number;
    /**
     * id assigned to input
     */
    id?: string;
}
/**
 * useCheckbox that provides all the state and focus management logic
 * for a checkbox. It is consumed by the `Checkbox` component
 *
 * @see Docs https://chakra-ui.com/components/useCheckbox
 */
export declare function useCheckbox(props?: UseCheckboxProps): {
    state: {
        isInvalid: boolean | undefined;
        isFocused: boolean;
        isChecked: boolean;
        isActive: boolean;
        isHovered: boolean;
        isIndeterminate: boolean | undefined;
        isDisabled: boolean | undefined;
        isReadOnly: boolean | undefined;
        isRequired: boolean | undefined;
    };
    getCheckboxProps: PropGetter<any, {}>;
    getInputProps: PropGetter<any, {}>;
    getLabelProps: PropGetter<any, {}>;
    htmlProps: {};
};
export declare type UseCheckboxReturn = ReturnType<typeof useCheckbox>;
